document.addEventListener('DOMContentLoaded', () => {
  const goalForm = document.getElementById('goalForm');
  const activeGoals = document.getElementById('activeGoals');

  // Load existing goals from localStorage
  let goals = JSON.parse(localStorage.getItem('goals')) || [];
  
  function saveGoal(goal) {
    goals.push(goal);
    localStorage.setItem('goals', JSON.stringify(goals));
    displayGoals();
  }

  function displayGoals() {
    activeGoals.innerHTML = '';
    goals.forEach((goal, index) => {
      const goalElement = document.createElement('div');
      goalElement.classList.add('goal-item');
      
      const deadline = new Date(goal.deadline);
      const timeLeft = deadline - new Date();
      
      goalElement.innerHTML = `
        <h3>${goal.text}</h3>
        <p>Deadline: ${deadline.toLocaleDateString()} ${deadline.toLocaleTimeString()}</p>
        <p>Time left: ${Math.ceil(timeLeft / (1000 * 60 * 60 * 24))} days</p>
      `;
      
      activeGoals.appendChild(goalElement);
    });
  }

  function checkDeadlines() {
    const now = new Date();
    goals = goals.filter(goal => {
      const deadline = new Date(goal.deadline);
      if (deadline <= now) {
        // In a real implementation, this would send an email using a backend service
        console.log(`Sending email for goal: ${goal.text} to ${goal.email}`);
        return false;
      }
      return true;
    });
    localStorage.setItem('goals', JSON.stringify(goals));
    displayGoals();
  }

  goalForm.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const goal = {
      text: document.getElementById('goalInput').value,
      deadline: document.getElementById('deadlineInput').value,
      email: document.getElementById('emailInput').value,
      created: new Date()
    };
    
    saveGoal(goal);
    goalForm.reset();
  });

  // Check deadlines every minute
  setInterval(checkDeadlines, 60000);
  
  // Initial display
  displayGoals();
});
